@@ -460,10 +460,12 @@ class PrivateStage(BaseStage):
         self._set_versiondata(metadata)
 
     def key_projversions(self, name):
+        name = self.get_projectname_perstage(name) or name
         return self.keyfs.PROJVERSIONS(
             user=self.user.name, index=self.index, name=name)
 
     def key_projversion(self, name, version):
+        name = self.get_projectname_perstage(name) or name
         return self.keyfs.PROJVERSION(
             user=self.user.name, index=self.index, name=name, version=version)
 
@@ -700,7 +702,8 @@ class LinkStore:
         linkdicts.append(new_linkdict)
         threadlog.info("added %r link %s", rel, file_entry.relpath)
         self._mark_dirty()
-        return ELink(self, new_linkdict, self.projectname, self.version)
+        return ELink(self.filestore, new_linkdict, self.projectname,
+                     self.version)
 
 
 def normalize_bases(model, bases):
